==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_uk_UA.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk_UA" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Пристрій використовується</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Надіслати останній відеофайл</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Надіслати електронною поштою один або кілька відеофайлів</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Надіслати</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Відеофайл буде представлений у вкладенні</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Виберіть один або кілька файлів</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>З рамкою</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Пристрій використовується</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Весь екран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Вікно</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Збільшення</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По замовчуванню</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Кодек</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записувати курсор миші</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Зберегти в теку</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Програвач</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Згортати Vokoscreen під час запису</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Надіслати</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Час запису</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Розмір в КБ</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Розмір екрану що записується</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Налаштування частоти</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Зворотній відлік</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Відтворити останній відеофайл</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Надіслати відеофайл</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Виберіть один або декілька пристроїв</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Фактична кількість кадрів в секунду</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Розсилка</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Підримка</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Розробник</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадри</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Бета OpenSUSE</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Зробити внесок</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Програма для запису</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переклади</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Джерельний код</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Показати значок на панелі</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Доступна нова версія</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Відеокодек</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Аудіокодек</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Веб-камера</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Виберіть веб-камеру</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_uk_UA.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk_UA" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Пристрій використовується</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Надіслати останній відеофайл</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Надіслати електронною поштою один або кілька відеофайлів</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Надіслати</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Відеофайл буде представлений у вкладенні</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Виберіть один або кілька файлів</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>З рамкою</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Пристрій використовується</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Весь екран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Вікно</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Збільшення</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По замовчуванню</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Кодек</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записувати курсор миші</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Зберегти в теку</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Програвач</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Згортати Vokoscreen під час запису</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Надіслати</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Час запису</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Розмір в КБ</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Розмір екрану що записується</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Налаштування частоти</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Зворотній відлік</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Відтворити останній відеофайл</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Надіслати відеофайл</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Виберіть один або декілька пристроїв</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Фактична кількість кадрів в секунду</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Підримка</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Розробник</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадри</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Зробити внесок</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Програма для запису</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переклади</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Джерельний код</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Показати значок на панелі</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Доступна нова версія</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Відеокодек</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Аудіокодек</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Веб-камера</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Виберіть веб-камеру</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
